aboutsummaryrefslogtreecommitdiffstats
path: root/png.h
diff options
context:
space:
mode:
authorEric Vannier <evannier@google.com>2011-07-20 17:03:29 -0700
committerKenny Root <kroot@google.com>2011-07-21 10:35:54 -0700
commit66dce0da6a5db51ee0c2875517d3a6ca6cbbe53d (patch)
tree7a375165c96b754d82ba1b6c304084645a5197bf /png.h
parent6acf3dd4a350c51fd2b72ec990b7da6d5657e52a (diff)
downloadexternal_libpng-66dce0da6a5db51ee0c2875517d3a6ca6cbbe53d.zip
external_libpng-66dce0da6a5db51ee0c2875517d3a6ca6cbbe53d.tar.gz
external_libpng-66dce0da6a5db51ee0c2875517d3a6ca6cbbe53d.tar.bz2
Upgrading libpng to 1.2.46 to fix a few vulnerabilities.
Bug: 5057432 Bug: 5055636 Change-Id: I9e1b51881386aa9f574a38abc844e036baef9091
Diffstat (limited to 'png.h')
-rw-r--r--png.h34
1 files changed, 21 insertions, 13 deletions
diff --git a/png.h b/png.h
index a3c21b9..d379dea 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.44 - June 26, 2010
- * Copyright (c) 1998-2010 Glenn Randers-Pehrson
+ * libpng version 1.2.46 - July 9, 2011
+ * Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.44 - June 26, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -231,7 +231,7 @@
* 1.2.37beta01-03 13 10237 12.so.0.37[.0]
* 1.2.37rc01 13 10237 12.so.0.37[.0]
* 1.2.37 13 10237 12.so.0.37[.0]
- * 1.2.45 10 10045 12.so.0.45[.0]
+ * 1.0.45 10 10045 12.so.0.45[.0]
* 1.0.46 10 10046 10.so.0.46[.0]
* 1.2.38beta01 13 10238 12.so.0.38[.0]
* 1.2.38rc01-03 13 10238 12.so.0.38[.0]
@@ -262,6 +262,14 @@
* 1.2.44beta01-03 13 10244 12.so.0.44[.0]
* 1.2.44rc01-03 13 10244 12.so.0.44[.0]
* 1.2.44 13 10244 12.so.0.44[.0]
+ * 1.2.45beta01-03 13 10245 12.so.0.45[.0]
+ * 1.0.55rc01 10 10055 10.so.0.55[.0]
+ * 1.2.45rc01 13 10245 12.so.0.45[.0]
+ * 1.0.55 10 10055 10.so.0.55[.0]
+ * 1.2.45 13 10245 12.so.0.45[.0]
+ * 1.2.46rc01-02 13 10246 12.so.0.46[.0]
+ * 1.0.56 10 10056 10.so.0.56[.0]
+ * 1.2.46 13 10246 12.so.0.46[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -293,8 +301,8 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.44, June 26, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
*
@@ -405,13 +413,13 @@
* Y2K compliance in libpng:
* =========================
*
- * June 26, 2010
+ * July 9, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.44 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -467,9 +475,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.44"
+#define PNG_LIBPNG_VER_STRING "1.2.46"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.44 - June 26, 2010\n"
+ " libpng version 1.2.46 - July 9, 2011\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -477,7 +485,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 2
-#define PNG_LIBPNG_VER_RELEASE 44
+#define PNG_LIBPNG_VER_RELEASE 46
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
@@ -507,7 +515,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10244 /* 1.2.44 */
+#define PNG_LIBPNG_VER 10246 /* 1.2.46 */
#ifndef PNG_VERSION_INFO_ONLY
/* Include the compression library's header */
@@ -1600,7 +1608,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_44;
+typedef png_structp version_1_2_46;
typedef png_struct FAR * FAR * png_structpp;
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.44 - June 26, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.46 - July 9, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -293,8 +301,8 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.44, June 26, 2010, are
- * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.46, July 9, 2011, are
+ * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -405,13 +413,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.44 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.46 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*